#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.6.1
visibility:           public
id:                   http-api-data-0.6.1-Jb92qtiBoSGDPE9f6KyoB3
key:                  http-api-data-0.6.1-Jb92qtiBoSGDPE9f6KyoB3
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  92738d5dd9d1076d071fc9d5e5a29b84
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.6.1-Jb92qtiBoSGDPE9f6KyoB3
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    http-types-0.12.4-5BZtRmLQcWTCOOFKM75zCu
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-iso8601-0.1.1.1-EvsX4ZtC61OEN26vYljnMZ
    time-compat-1.9.9-F5CZ2IFajUK1gKnrRNatir transformers-0.6.1.0
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    uuid-types-1.0.6-Cts4LAgfNqGLlNq2heOTT6

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

